@@ -71,7 +71,8 @@ class JSONWebSignature(crypto.Signable):
         """Return a byte-sequence holding the data that needs to be signed
         for the :class:`JSONWebSignature`.
         """
-        return self.get_jose_header(signer) + b'.' + bytes(self.payload)
+        message = self.get_jose_header(signer) + b'.' + bytes(self.payload)
+        return signer.digest(message)
 
     def is_signed(self) -> bool:
         """Return a boolean indicating if the :class:`JSONWebSignature`
@@ -91,10 +92,11 @@ class JSONWebSignature(crypto.Signable):
         """Verify the :class:`JSONWebSignature` with the given key. Return
         a boolean indicating if the signature was valid.
         """
-        return await self.signature.verify(key, bytes.join(b'.', [
+        digest = self.signature.algorithm.digest(bytes.join(b'.', [
             bytes(self.header),
             bytes(self.payload)
         ]))
+        return self.signature.verify(key, digest)
 
     def __str__(self):
         return str.join('.', [
