@@ -145,5 +145,8 @@ class JSONWebToken:
     def __bytes__(self):
         return base64url_encode(json_encode(self.claims))
 
+    def __iter__(self):
+        return iter(dict.items(self.claims))
+
     def __str__(self):
         return bytes.decode(bytes(self))
